@@ -32,6 +32,7 @@
 #include "mainwindow.h"
 
 #include <QDBusConnection>
+#include <QDir>
 
 using Tellico::ApplicationInterface;
 using Tellico::CollectionInterface;
@@ -78,11 +79,13 @@ bool ApplicationInterface::showEntry(int id)  {
   return m_mainWindow->showEntry(id);
 }
 
-bool ApplicationInterface::importFile(Tellico::Import::Format format, const QUrl& url, Tellico::Import::Action action) {
+bool ApplicationInterface::importFile(Tellico::Import::Format format, const QString& file, Tellico::Import::Action action) {
+  const QUrl url = QUrl::fromUserInput(file, QDir::currentPath(), QUrl::AssumeLocalFile);
   return m_mainWindow->importFile(format, url, action);
 }
 
-bool ApplicationInterface::exportCollection(Tellico::Export::Format format, const QUrl& url, bool filtered) {
+bool ApplicationInterface::exportCollection(Tellico::Export::Format format, const QString& file, bool filtered) {
+  const QUrl url = QUrl::fromUserInput(file, QDir::currentPath(), QUrl::AssumeLocalFile);
   return m_mainWindow->exportCollection(format, url, filtered);
 }
 
