@@ -142,7 +142,7 @@ void GoogleBookFetcher::doSearch(const QString& term_) {
       break;
 
     default:
-      myWarning() << "key not recognized:" << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       return;
   }
   u.setQuery(q);
